@@ -21,7 +21,6 @@ def convolve(input,
         depth=depth,
         boundary=boundary,
         dtype=input.dtype,
-        name=scipy.ndimage.filters.convolve.__name__,
         weights=weights,
         mode=mode,
         cval=cval,
@@ -46,7 +45,6 @@ def correlate(input,
         depth=depth,
         boundary=boundary,
         dtype=input.dtype,
-        name=scipy.ndimage.filters.correlate.__name__,
         weights=weights,
         mode=mode,
         cval=cval,
